==> mktcenter-service-1.0.2-vg-20220801.031911-10-sources.jar: com/bizvane/mktcenterservice/models/vo/SendMessageVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import java.util.Date;

/**
 * @Author: lijunwei
 * @Time: 2018/11/2 10:48
 */
public class SendMessageVO {
    private Long mktTaskId;
    private Integer taskType;
    private String taskName;
    private Long sysCompanyId;
    private Long sysBrandId;
    private String msgContent;
   // true(1:微信线上会员(小程序或微信粉丝) )
    private Boolean exceptWechat;
    private String msgType;
    private Integer points;
    private Date startTime;
    private Date endTime;
    private String type;
    //微信模板新增字段
    private String templateMsgId;
    private String msgTail;
    private String first;
    private String link;

    private String  organizationCode;
    private String merchantId;//商户id
    private String templateCodeIntl;
    private String templateCodeCn;
    private Integer msgTaskType;//任务类型 1.验证码 2.活动 3.任务 4.分组
    private Long msgTaskId;//任务id(对应业务id)
    private String msgTaskCode;//任务编号
    //发送消息的品牌id
    private Long sendBrandId;
    //发送消息的微信模板type,对应t_msg_wx_temp的模板Type
    private String wxTemplateType;
    //任务描述
    private String taskInfo;
    private String businessModuleCode;

    public String getBusinessModuleCode() {
        return businessModuleCode;
    }

    public void setBusinessModuleCode(String businessModuleCode) {
        this.businessModuleCode = businessModuleCode;
    }

    public String getTemplateMsgId() {
        return templateMsgId;
    }

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public void setTemplateMsgId(String templateMsgId) {
        this.templateMsgId = templateMsgId;
    }

    public String getMsgTail() {
        return msgTail;
    }

    public void setMsgTail(String msgTail) {
        this.msgTail = msgTail;
    }

    public String getFirst() {
        return first;
    }

    public void setFirst(String first) {
        this.first = first;
    }

    public Long getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(Long mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMsgContent() {
        return msgContent;
    }

    public void setMsgContent(String msgContent) {
        this.msgContent = msgContent;
    }

    public Boolean getExceptWechat() {
        return exceptWechat;
    }

    public void setExceptWechat(Boolean exceptWechat) {
        this.exceptWechat = exceptWechat;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getMsgType() {
        return msgType;
    }

    public void setMsgType(String msgType) {
        this.msgType = msgType;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }

    public String getTemplateCodeIntl() {
        return templateCodeIntl;
    }

    public void setTemplateCodeIntl(String templateCodeIntl) {
        this.templateCodeIntl = templateCodeIntl;
    }

    public String getTemplateCodeCn() {
        return templateCodeCn;
    }

    public void setTemplateCodeCn(String templateCodeCn) {
        this.templateCodeCn = templateCodeCn;
    }

    public Integer getMsgTaskType() {
        return msgTaskType;
    }

    public void setMsgTaskType(Integer msgTaskType) {
        this.msgTaskType = msgTaskType;
    }

    public Long getMsgTaskId() {
        return msgTaskId;
    }

    public void setMsgTaskId(Long msgTaskId) {
        this.msgTaskId = msgTaskId;
    }

    public String getMsgTaskCode() {
        return msgTaskCode;
    }

    public void setMsgTaskCode(String msgTaskCode) {
        this.msgTaskCode = msgTaskCode;
    }

    public String getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(String merchantId) {
        this.merchantId = merchantId;
    }

    public Long getSendBrandId() {
        return sendBrandId;
    }

    public void setSendBrandId(Long sendBrandId) {
        this.sendBrandId = sendBrandId;
    }

    public String getWxTemplateType() {
        return wxTemplateType;
    }

    public void setWxTemplateType(String wxTemplateType) {
        this.wxTemplateType = wxTemplateType;
    }

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }
}

==> mktcenter-service-1.5.7-vg-20231123.095934-4-sources.jar: com/bizvane/mktcenterservice/models/vo/SendMessageVO.java <==
package com.bizvane.mktcenterservice.models.vo;

import java.util.Date;

/**
 * @Author: lijunwei
 * @Time: 2018/11/2 10:48
 */
public class SendMessageVO {
    private Long mktTaskId;
    private Integer taskType;
    private String taskName;
    private Long sysCompanyId;
    private Long sysBrandId;
    private String msgContent;
   // true(1:微信线上会员(小程序或微信粉丝) )
    private Boolean exceptWechat;
    private String msgType;
    private Integer points;
    private Date startTime;
    private Date endTime;
    private String type;
    //微信模板新增字段
    private String templateMsgId;
    private String msgTail;
    private String first;
    private String link;

    private String  organizationCode;
    private String merchantId;//商户id
    private String templateCodeIntl;
    private String templateCodeCn;
    private Integer msgTaskType;//任务类型 1.验证码 2.活动 3.任务 4.分组
    private Long msgTaskId;//任务id(对应业务id)
    private String msgTaskCode;//任务编号
    //发送消息的品牌id
    private Long sendBrandId;
    //发送消息的微信模板type,对应t_msg_wx_temp的模板Type
    private String wxTemplateType;
    //任务描述
    private String taskInfo;
    private String businessModuleCode;

    // 会员code
    private String memberCode;

    public String getBusinessModuleCode() {
        return businessModuleCode;
    }

    public void setBusinessModuleCode(String businessModuleCode) {
        this.businessModuleCode = businessModuleCode;
    }

    public String getTemplateMsgId() {
        return templateMsgId;
    }

    public String getLink() {
        return link;
    }

    public void setLink(String link) {
        this.link = link;
    }

    public void setTemplateMsgId(String templateMsgId) {
        this.templateMsgId = templateMsgId;
    }

    public String getMsgTail() {
        return msgTail;
    }

    public void setMsgTail(String msgTail) {
        this.msgTail = msgTail;
    }

    public String getFirst() {
        return first;
    }

    public void setFirst(String first) {
        this.first = first;
    }

    public Long getMktTaskId() {
        return mktTaskId;
    }

    public void setMktTaskId(Long mktTaskId) {
        this.mktTaskId = mktTaskId;
    }

    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMsgContent() {
        return msgContent;
    }

    public void setMsgContent(String msgContent) {
        this.msgContent = msgContent;
    }

    public Boolean getExceptWechat() {
        return exceptWechat;
    }

    public void setExceptWechat(Boolean exceptWechat) {
        this.exceptWechat = exceptWechat;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getMsgType() {
        return msgType;
    }

    public void setMsgType(String msgType) {
        this.msgType = msgType;
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public String getOrganizationCode() {
        return organizationCode;
    }

    public void setOrganizationCode(String organizationCode) {
        this.organizationCode = organizationCode;
    }

    public String getTemplateCodeIntl() {
        return templateCodeIntl;
    }

    public void setTemplateCodeIntl(String templateCodeIntl) {
        this.templateCodeIntl = templateCodeIntl;
    }

    public String getTemplateCodeCn() {
        return templateCodeCn;
    }

    public void setTemplateCodeCn(String templateCodeCn) {
        this.templateCodeCn = templateCodeCn;
    }

    public Integer getMsgTaskType() {
        return msgTaskType;
    }

    public void setMsgTaskType(Integer msgTaskType) {
        this.msgTaskType = msgTaskType;
    }

    public Long getMsgTaskId() {
        return msgTaskId;
    }

    public void setMsgTaskId(Long msgTaskId) {
        this.msgTaskId = msgTaskId;
    }

    public String getMsgTaskCode() {
        return msgTaskCode;
    }

    public void setMsgTaskCode(String msgTaskCode) {
        this.msgTaskCode = msgTaskCode;
    }

    public String getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(String merchantId) {
        this.merchantId = merchantId;
    }

    public Long getSendBrandId() {
        return sendBrandId;
    }

    public void setSendBrandId(Long sendBrandId) {
        this.sendBrandId = sendBrandId;
    }

    public String getWxTemplateType() {
        return wxTemplateType;
    }

    public void setWxTemplateType(String wxTemplateType) {
        this.wxTemplateType = wxTemplateType;
    }

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
}
